@@ -35,16 +35,16 @@ class Avto(models.Model):
     description = models.CharField(max_length=255, blank=True, verbose_name='Description')
     data1 = models.CharField(max_length=255, blank=True, verbose_name='Description (data1)')
     data2 = models.CharField(max_length=255, blank=True, verbose_name='Description (data2)')
-    img1 = models.FileField(upload_to='uploads/%Y/%m/%d/', verbose_name='img1')
-    img2 = models.FileField(upload_to='uploads/%Y/%m/%d/', blank=True, verbose_name='img2')
-    img3 = models.FileField(upload_to='uploads/%Y/%m/%d/', blank=True, verbose_name='img3')
-    img4 = models.FileField(upload_to='uploads/%Y/%m/%d/', blank=True, verbose_name='img4')
-    img5 = models.FileField(upload_to='uploads/%Y/%m/%d/', blank=True, verbose_name='img5')
-    img6 = models.FileField(upload_to='uploads/%Y/%m/%d/', blank=True, verbose_name='img6')
-    img7 = models.FileField(upload_to='uploads/%Y/%m/%d/', blank=True, verbose_name='img7')
-    img8 = models.FileField(upload_to='uploads/%Y/%m/%d/', blank=True, verbose_name='img8')
-    img9 = models.FileField(upload_to='uploads/%Y/%m/%d/', blank=True, verbose_name='img9')
-    img10 = models.FileField(upload_to='uploads/%Y/%m/%d/', blank=True, verbose_name='img10')
+    img1 = models.FileField(upload_to='/uploads/%Y/%m/%d/', verbose_name='img1')
+    img2 = models.FileField(upload_to='/uploads/%Y/%m/%d/', blank=True, verbose_name='img2')
+    img3 = models.FileField(upload_to='/uploads/%Y/%m/%d/', blank=True, verbose_name='img3')
+    img4 = models.FileField(upload_to='/uploads/%Y/%m/%d/', blank=True, verbose_name='img4')
+    img5 = models.FileField(upload_to='/uploads/%Y/%m/%d/', blank=True, verbose_name='img5')
+    img6 = models.FileField(upload_to='/uploads/%Y/%m/%d/', blank=True, verbose_name='img6')
+    img7 = models.FileField(upload_to='/uploads/%Y/%m/%d/', blank=True, verbose_name='img7')
+    img8 = models.FileField(upload_to='/uploads/%Y/%m/%d/', blank=True, verbose_name='img8')
+    img9 = models.FileField(upload_to='/uploads/%Y/%m/%d/', blank=True, verbose_name='img9')
+    img10 = models.FileField(upload_to='/uploads/%Y/%m/%d/', blank=True, verbose_name='img10')
     url = models.CharField(max_length=255, blank=True, verbose_name='img1')
     factory_options1 = models.TextField(blank=True, verbose_name='Factory Options1')
     factory_options2 = models.TextField(blank=True, verbose_name='Factory Options2', default='')
@@ -73,13 +73,13 @@ class Avto(models.Model):
     location = models.CharField(blank=True, max_length=20, default='-', choices=locations, verbose_name="current location (country)")
     posted_by = models.ForeignKey(settings.AUTH_USER_MODEL, on_delete=models.CASCADE, default=22)
     STATUS = (("AVAILABLE", "Available"), ("BOOKED", "Booked"), ("SOLD", "Sold"))
-    condition = models.CharField(blank=True, default=None, choices=conditions, verbose_name='Status of vehicle, repaired/damaged')
+    condition = models.CharField(max_length=16, blank=True, default=None, choices=conditions, verbose_name='Status of vehicle, repaired/damaged')
     status = models.CharField(max_length=16, blank=True, verbose_name='Status of ad', choices=STATUS, default='available')
 
     def get_fields(self):
         return [(field.verbose_name, field.value_from_object(self)) for field in self.__class__._meta.fields]
 
     class Meta:
-        verbose_name = "avto objects"
+        verbose_name = "avto object (Site iaai.com)"
         ordering = ['id']
         app_label = 'avto'
